@@ -274,7 +274,7 @@ $string['requesttypedelete'] = 'Delete all of my personal data';
 $string['requesttypedeleteshort'] = 'Delete';
 $string['requesttypeexport'] = 'Export all of my personal data';
 $string['requesttypeexportshort'] = 'Export';
-$string['requesttypeothers'] = 'General inquiry';
+$string['requesttypeothers'] = 'General enquiry';
 $string['requesttypeothersshort'] = 'Message';
 $string['requireallenddatesforuserdeletion'] = 'Consider courses without end date as active';
 $string['requireallenddatesforuserdeletion_desc'] = 'When calculating user expiry, several factors are considered:
