@@ -1,24 +1,18 @@
-<?PHP // $Id: pix.php,v 1.28.2.3 2010/04/10 00:17:45 iarenaza Exp $
+<?php
       // This function fetches math. images from the data directory
       // If not, it obtains the corresponding TeX expression from the cache_tex db table
       // and uses mimeTeX to create the image file
 
-    $nomoodlecookie = true;     // Because it interferes with caching
+// disable moodle specific debug messages and any errors in output
+define('NO_DEBUG_DISPLAY', true);
+define('NO_MOODLE_COOKIES', true); // Because it interferes with caching
 
     require_once('../../config.php');
 
-    if (empty($CFG->textfilters)) {
-        error ('Filter not enabled!');
-    } else {
-        $filters = explode(',', $CFG->textfilters);
-        if (array_search('filter/tex', $filters) === FALSE) {
-            error ('Filter not enabled!');
-        }
+    if (!filter_is_enabled('tex')) {
+        print_error('filternotenabled');
     }
 
-    // disable moodle specific debug messages
-    disable_debugging();
-
     require_once($CFG->libdir.'/filelib.php');
     require_once($CFG->dirroot.'/filter/tex/lib.php');
     require_once($CFG->dirroot.'/filter/tex/latex.php');
@@ -26,7 +20,7 @@
     $cmd    = '';               // Initialise these variables
     $status = '';
 
-    $relativepath = get_file_argument('pix.php');
+    $relativepath = get_file_argument();
 
     $args = explode('/', trim($relativepath, '/'));
 
@@ -34,26 +28,28 @@
         $image    = $args[0];
         $pathname = $CFG->dataroot.'/filter/tex/'.$image;
     } else {
-        error('No valid arguments supplied');
+        print_error('invalidarguments', 'error');
     }
 
     if (!file_exists($pathname)) {
-        $md5 = str_replace(".{$CFG->filter_tex_convertformat}",'',$image);
-        if ($texcache = get_record('cache_filters', 'filter', 'tex', 'md5key', $md5)) {
+        $convertformat = get_config('filter_tex', 'convertformat');
+        if (strpos($image, '.png')) {
+            $convertformat = 'png';
+        }
+        $md5 = str_replace(".{$convertformat}", '', $image);
+        if ($texcache = $DB->get_record('cache_filters', array('filter'=>'tex', 'md5key'=>$md5))) {
             if (!file_exists($CFG->dataroot.'/filter/tex')) {
                 make_upload_directory('filter/tex');
             }
 
             // try and render with latex first
             $latex = new latex();
-            $density = $CFG->filter_tex_density;
-            $background = $CFG->filter_tex_latexbackground;
-            $texexp = html_entity_decode($texcache->rawtext);
-            $latex_path = $latex->render($texexp, $md5, 12, $density, $background);
-            if ($latex_path) {
-                copy($latex_path, $pathname);
-                $latex->clean_up($md5);
-
+            $density = get_config('filter_tex', 'density');
+            $background = get_config('filter_tex', 'latexbackground');
+            $texexp = $texcache->rawtext; // the entities are now decoded before inserting to DB
+            $lateximage = $latex->render($texexp, $image, 12, $density, $background);
+            if ($lateximage) {
+                copy($lateximage, $pathname);
             } else {
                 // failing that, use mimetex
                 $texexp = $texcache->rawtext;
@@ -61,7 +57,7 @@
                 $texexp = str_replace('&gt;', '>', $texexp);
                 $texexp = preg_replace('!\r\n?!', ' ', $texexp);
                 $texexp = '\Large '.$texexp;
-                $cmd = tex_filter_get_cmd($pathname, $texexp);
+                $cmd = filter_tex_get_cmd($pathname, $texexp);
                 system($cmd, $status);
             }
         }
@@ -80,4 +76,3 @@
             echo "Please turn on debug mode in site configuration to see more info here.";
         }
     }
-?>
