@@ -46,7 +46,7 @@ $string['currentusers'] = 'Current users';
 $string['deletesession'] = 'Delete this session';
 $string['deletesessionsure'] = 'Are you sure you want to delete this session?';
 $string['donotusechattime'] = 'Don\'t publish any chat times';
-$string['enterchat'] = 'Click here to enter the chat now';
+$string['enterchat'] = 'Enter the chat';
 $string['errornousers'] = 'Could not find any users!';
 $string['explaingeneralconfig'] = 'These settings are <strong>always</strong> used';
 $string['explainmethoddaemon'] = 'These settings only have an effect if \'Chat server daemon\' is selected as chat method.';
@@ -63,6 +63,7 @@ $string['chat:readlog'] = 'View chat logs';
 $string['chatreport'] = 'Chat sessions';
 $string['chat:talk'] = 'Talk in a chat';
 $string['chattime'] = 'Next chat time';
+$string['nextchattime'] = 'Next chat time:';
 $string['chat:view'] = 'View chat activity';
 $string['entermessage'] = "Enter your message";
 $string['eventmessagesent'] = 'Message sent';
@@ -70,8 +71,14 @@ $string['eventsessionsviewed'] = 'Sessions viewed';
 $string['idle'] = 'Idle';
 $string['indicator:cognitivedepth'] = 'Chat cognitive';
 $string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Chat activity.';
+$string['indicator:cognitivedepthdef'] = 'Chat cognitive';
+$string['indicator:cognitivedepthdef_help'] = 'The participant has reached this percentage of the cognitive engagement offered by the Chat activities during this analysis interval (Levels = No view, View, Submit, View feedback, Comment on feedback)';
+$string['indicator:cognitivedepthdef_link'] = 'Learning_analytics_indicators#Cognitive_depth';
 $string['indicator:socialbreadth'] = 'Chat social';
 $string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Chat activity.';
+$string['indicator:socialbreadthdef'] = 'Chat social';
+$string['indicator:socialbreadthdef_help'] = 'The participant has reached this percentage of the social engagement offered by the Chat activities during this analysis interval (Levels = No participation, Participant alone, Participant with others)';
+$string['indicator:socialbreadthdef_link'] = 'Learning_analytics_indicators#Social_breadth';
 $string['inputarea'] = 'Input area';
 $string['invalidid'] = 'Could not find that chat room!';
 $string['list_all_sessions'] = 'List all sessions.';
@@ -103,7 +110,6 @@ Chats are especially useful when the group chatting is not able to meet face-to-
 $string['modulename_link'] = 'mod/chat/view';
 $string['modulenameplural'] = 'Chats';
 $string['neverdeletemessages'] = 'Never delete messages';
-$string['nextsession'] = 'Next scheduled session';
 $string['no_complete_sessions_found'] = 'No complete sessions found.';
 $string['noguests'] = 'The chat is not open to guests';
 $string['nochat'] = 'No chat found';
@@ -117,6 +123,7 @@ $string['nopermissiontoseethechatlog'] = 'You don\'t have permission to see the
 $string['oldping'] = 'Disconnect timeout';
 $string['page-mod-chat-x'] = 'Any chat module page';
 $string['pastchats'] = 'Past chat sessions';
+$string['pastsessions'] = 'Past sessions';
 $string['pluginadministration'] = 'Chat administration';
 $string['pluginname'] = 'Chat';
 $string['privacy:metadata:chat_messages_current'] = 'Current chat session. This data is temporary and is deleted after the chat session is deleted';
@@ -151,7 +158,7 @@ $string['serverip'] = 'Server ip';
 $string['servermax'] = 'Max users';
 $string['serverport'] = 'Server port';
 $string['sessions'] = 'Chat sessions';
-$string['sessionstart'] = 'The next chat session will start on {$a->date}, ({$a->fromnow} from now)';
+$string['sessionstartsin'] = 'The next chat session will start {$a} from now.';
 $string['strftimemessage'] = '%H:%M';
 $string['studentseereports'] = 'Everyone can view past sessions';
 $string['studentseereports_help'] = 'If set to No, only users have mod/chat:readlog capability are able to see the chat logs';
@@ -167,4 +174,10 @@ $string['usingchat_help'] = 'The chat module contains some features to make chat
 * Emoting - You can start a line with "/me" or ":" to emote, for example if your name is Kim and you type ":laughs!" or "/me laughs!" then everyone will see "Kim laughs!"
 * Beeps - You can send a sound to other participants by clicking the "beep" link next to their name. A useful shortcut to beep all the people in the chat at once is to type "beep all".
 * HTML - If you know some HTML code, you can use it in your text to do things like insert images, play sounds or create different coloured text';
-$string['viewreport'] = 'View past chat sessions';
+$string['viewreport'] = 'Past sessions';
+
+// Deprecated since Moodle 3.11.
+$string['sessionstart'] = 'The next chat session will start on {$a->date}, ({$a->fromnow} from now)';
+
+// Deprecated since Moodle 4.0.
+$string['nextsession'] = 'Next scheduled session';
